# Generated by Django 3.2.4 on 2021-08-12 01:00

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0079_auto_20210812_0335"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="haemoglobin_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Haemoglobin",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="mch_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="MCH",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="mchc_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="MCHC",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="mcv_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="MCV",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="platelets_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(9999.0),
                ],
                verbose_name="Platelets",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="wbc_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="WBC",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="albumin_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Serum albumin",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alp_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="ALP",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="amylase_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ast_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="AST",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ggt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="GGT",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="chol_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Total Cholesterol",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="egfr_units",
            field=models.CharField(
                blank=True,
                choices=[("mL/min/1.73m2", "mL/min/1.73m2")],
                default="mL/min/1.73m2",
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="egfr_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=8,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="urea_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Urea (BUN)",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="uric_acid_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=10,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Uric Acid",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="haemoglobin_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Haemoglobin",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="mch_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="MCH",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="mchc_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="MCHC",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="mcv_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="MCV",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="platelets_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(9999.0),
                ],
                verbose_name="Platelets",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="wbc_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="WBC",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="albumin_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Serum albumin",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alp_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="ALP",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="amylase_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ast_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="AST",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ggt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="GGT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="chol_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Total Cholesterol",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="egfr_units",
            field=models.CharField(
                blank=True,
                choices=[("mL/min/1.73m2", "mL/min/1.73m2")],
                default="mL/min/1.73m2",
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="egfr_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=8,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="urea_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=6,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Urea (BUN)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="uric_acid_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=10,
                null=True,
                validators=[django.core.validators.MinValueValidator(0.0)],
                verbose_name="Uric Acid",
            ),
        ),
    ]



# Generated by Django 3.2.13 on 2022-09-27 23:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0152_auto_20220925_0509"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstudymedication",
            name="refill",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                help_text="If NO, set refill_start_datetime equal to the refill_end_datetime",
                max_length=15,
                verbose_name="Will the subject receive study medication for this visit",
            ),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="refill",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                help_text="If NO, set refill_start_datetime equal to the refill_end_datetime",
                max_length=15,
                verbose_name="Will the subject receive study medication for this visit",
            ),
        ),
    ]



from django.contrib import admin
from django.urls.base import reverse
from django.urls.exceptions import NoReverseMatch
from django_audit_fields.admin import audit_fieldset_tuple
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin

from ..admin_site import meta_screening_admin
from ..forms import SubjectRefusalForm
from ..models import SubjectRefusal


@admin.register(SubjectRefusal, site=meta_screening_admin)
class SubjectRefusalAdmin(ModelAdminSubjectDashboardMixin, SimpleHistoryAdmin):

    form = SubjectRefusalForm

    autocomplete_fields = ["subject_screening"]

    post_url_on_delete_name = "screening_listboard_url"
    subject_listboard_url_name = "screening_listboard_url"
    subject_dashboard_url_name = "screening_listboard_url"

    fieldsets = (
        [
            None,
            {
                "fields": (
                    "subject_screening",
                    "report_datetime",
                    "reason",
                    "other_reason",
                )
            },
        ],
        audit_fieldset_tuple,
    )

    list_display = (
        "subject_screening",
        "report_datetime",
        "reason",
        "user_created",
        "created",
    )

    list_filter = ("report_datetime", "subject_screening__gender", "reason")

    search_fields = (
        "subject_screening__screening_identifier",
        "subject_screening__hospital_identifier",
        "subject_screening__initials",
    )

    radio_fields = {"reason": admin.VERTICAL}

    def get_subject_dashboard_url_kwargs(self, obj):
        return dict(screening_identifier=obj.screening_identifier)

    def view_on_site(self, obj):
        try:
            url = reverse(
                self.get_subject_dashboard_url_name(),
                kwargs=self.get_subject_dashboard_url_kwargs(obj),
            )
        except NoReverseMatch as e:
            if callable(super().view_on_site):
                url = super().view_on_site(obj)
            else:
                raise NoReverseMatch(f"{e}. See subject_dashboard_url_name for {repr(self)}.")
        return url



# Generated by Django 3.2.4 on 2021-07-09 17:56

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_utils.date
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_adverse_event", "0006_auto_20210425_1628"),
        ("meta_ae", "0005_auto_20210624_0225"),
    ]

    operations = [
        migrations.CreateModel(
            name="AeSponsorReview",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Report date and time",
                    ),
                ),
                (
                    "clinical_review_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date and time of clinical review: ",
                    ),
                ),
                (
                    "ae_classification_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "ae_type",
                    models.CharField(
                        choices=[
                            ("sae", "Serious Adverse Event / Reaction"),
                            ("aesi", "Adverse Event of Special Interest"),
                            ("susar", "Serious Unexpected Adverse Reaction"),
                        ],
                        max_length=25,
                        verbose_name="Type of event",
                    ),
                ),
                (
                    "study_drug_relation",
                    models.CharField(
                        choices=[
                            ("not_related", "Not related"),
                            ("unlikely_related", "Unlikely related"),
                            ("possibly_related", "Possibly related"),
                            ("probably_related", "Probably related"),
                            ("definitely_related", "Definitely related"),
                            ("N/A", "Not applicable"),
                        ],
                        max_length=25,
                        null=True,
                        verbose_name="Relationship to study drug:",
                    ),
                ),
                (
                    "ae_expected",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        null=True,
                        verbose_name="Based on the protocol, do you believe this event is expected?",
                    ),
                ),
                (
                    "ae_action_required",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        null=True,
                        verbose_name="If unexpected, do you believe further action is required?",
                    ),
                ),
                (
                    "investigator_comments",
                    models.TextField(
                        blank=True,
                        null=True,
                        verbose_name="This Clinical Reviewer's comments:",
                    ),
                ),
                (
                    "original_report_agreed",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="If No, explain in the narrative below",
                        max_length=15,
                        null=True,
                        verbose_name="Does this Clinical Reviewer agree with the original AE report?",
                    ),
                ),
                (
                    "narrative",
                    models.TextField(blank=True, null=True, verbose_name="Narrative"),
                ),
                (
                    "officials_notified",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date and time regulatory authorities notified",
                    ),
                ),
                (
                    "ae_classification",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_adverse_event.aeclassification",
                        verbose_name="Adverse Event (AE) Classification",
                    ),
                ),
                (
                    "ae_initial",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_ae.aeinitial",
                    ),
                ),
            ],
            options={
                "verbose_name": "AE Sponsor Review",
            },
        ),
        migrations.CreateModel(
            name="AeLocalReview",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Report date and time",
                    ),
                ),
                (
                    "clinical_review_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date and time of clinical review: ",
                    ),
                ),
                (
                    "ae_classification_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "ae_type",
                    models.CharField(
                        choices=[
                            ("sae", "Serious Adverse Event / Reaction"),
                            ("aesi", "Adverse Event of Special Interest"),
                            ("susar", "Serious Unexpected Adverse Reaction"),
                        ],
                        max_length=25,
                        verbose_name="Type of event",
                    ),
                ),
                (
                    "study_drug_relation",
                    models.CharField(
                        choices=[
                            ("not_related", "Not related"),
                            ("unlikely_related", "Unlikely related"),
                            ("possibly_related", "Possibly related"),
                            ("probably_related", "Probably related"),
                            ("definitely_related", "Definitely related"),
                            ("N/A", "Not applicable"),
                        ],
                        max_length=25,
                        null=True,
                        verbose_name="Relationship to study drug:",
                    ),
                ),
                (
                    "ae_expected",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        null=True,
                        verbose_name="Based on the protocol, do you believe this event is expected?",
                    ),
                ),
                (
                    "ae_action_required",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        null=True,
                        verbose_name="If unexpected, do you believe further action is required?",
                    ),
                ),
                (
                    "investigator_comments",
                    models.TextField(
                        blank=True,
                        null=True,
                        verbose_name="This Clinical Reviewer's comments:",
                    ),
                ),
                (
                    "original_report_agreed",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="If No, explain in the narrative below",
                        max_length=15,
                        null=True,
                        verbose_name="Does this Clinical Reviewer agree with the original AE report?",
                    ),
                ),
                (
                    "narrative",
                    models.TextField(blank=True, null=True, verbose_name="Narrative"),
                ),
                (
                    "officials_notified",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date and time regulatory authorities notified",
                    ),
                ),
                (
                    "ae_classification",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_adverse_event.aeclassification",
                        verbose_name="Adverse Event (AE) Classification",
                    ),
                ),
                (
                    "ae_initial",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_ae.aeinitial",
                    ),
                ),
            ],
            options={
                "verbose_name": "AE Local Review",
            },
        ),
    ]



# Generated by Django 2.2.6 on 2019-11-02 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("meta_lists", "0003_auto_20191102_0033")]

    operations = [
        migrations.CreateModel(
            name="NonAdherenceReasons",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={"ordering": ["display_index", "display_name"], "abstract": False},
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="meta_lists__id_5a7907_idx",
            ),
        ),
    ]



from django.apps import apps as django_apps
from django.utils.safestring import mark_safe
from edc_action_item.action_with_notification import ActionWithNotification
from edc_action_item.site_action_items import site_action_items
from edc_adverse_event.constants import DEATH_REPORT_ACTION
from edc_constants.constants import HIGH_PRIORITY, NOT_SURE, TBD, YES
from edc_lab_results import BLOOD_RESULTS_RFT_ACTION
from edc_ltfu.constants import LTFU_ACTION
from edc_offstudy.constants import END_OF_STUDY_ACTION
from edc_protocol_incident.action_items import (
    ProtocolIncidentAction as BaseProtocolIncidentAction,
)
from edc_transfer.action_items import SubjectTransferAction as BaseSubjectTransferAction
from edc_transfer.constants import SUBJECT_TRANSFER_ACTION

from meta_subject.constants import (
    DELIVERY_ACTION,
    MISSED_VISIT_ACTION,
    URINE_PREGNANCY_ACTION,
)

from .constants import (
    OFFSCHEDULE_ACTION,
    OFFSCHEDULE_PREGNANCY_ACTION,
    OFFSTUDY_MEDICATION_ACTION,
    PREGNANCY_NOTIFICATION_ACTION,
    UNBLINDING_REQUEST_ACTION,
    UNBLINDING_REVIEW_ACTION,
)
from .pregnancy_action_item_mixin import PregnancyActionItemMixin


class OffscheduleAction(ActionWithNotification):
    name = OFFSCHEDULE_ACTION
    display_name = "Submit Off-Schedule"
    notification_display_name = "Off-Schedule"
    parent_action_names = [
        UNBLINDING_REVIEW_ACTION,
        DEATH_REPORT_ACTION,
        LTFU_ACTION,
        BLOOD_RESULTS_RFT_ACTION,
    ]
    reference_model = "meta_prn.offschedule"
    show_link_to_changelist = True
    admin_site_name = "meta_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True

    def get_next_actions(self):
        pregnancy_notification = (
            django_apps.get_model("meta_prn.pregnancynotification")
            .objects.filter(subject_identifier=self.subject_identifier)
            .last()
        )

        if pregnancy_notification and pregnancy_notification.may_contact in [YES, NOT_SURE]:
            next_actions = [OFFSTUDY_MEDICATION_ACTION]
        else:
            next_actions = [OFFSTUDY_MEDICATION_ACTION, END_OF_STUDY_ACTION]
        return next_actions


class OffschedulePregnancyAction(ActionWithNotification):
    name = OFFSCHEDULE_PREGNANCY_ACTION
    display_name = "Submit Off-Schedule (Pregnancy)"
    notification_display_name = "Off-Schedule (Pregnancy)"
    parent_action_names = [
        UNBLINDING_REVIEW_ACTION,
        DEATH_REPORT_ACTION,
        LTFU_ACTION,
        DELIVERY_ACTION,
    ]
    reference_model = "meta_prn.offschedulepregnancy"
    show_link_to_changelist = True
    admin_site_name = "meta_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True

    def get_next_actions(self):
        next_actions = [END_OF_STUDY_ACTION]
        return next_actions


class EndOfStudyAction(ActionWithNotification):
    name = END_OF_STUDY_ACTION
    display_name = "Submit End of Study Report"
    notification_display_name = "End of Study Report"
    parent_action_names = [
        OFFSCHEDULE_ACTION,
        OFFSCHEDULE_PREGNANCY_ACTION,
    ]
    reference_model = "meta_prn.endofstudy"
    show_link_to_changelist = True
    admin_site_name = "meta_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True


class LossToFollowupAction(PregnancyActionItemMixin, ActionWithNotification):
    name = LTFU_ACTION
    display_name = "Submit Loss to Follow Up Report"
    notification_display_name = " Loss to Follow Up Report"
    parent_action_names = [MISSED_VISIT_ACTION]
    reference_model = "meta_prn.losstofollowup"
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "meta_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True

    def get_next_actions(self):
        next_actions = [self.get_next_offschedule_action(), OFFSTUDY_MEDICATION_ACTION]
        return next_actions


class PregnancyNotificationAction(ActionWithNotification):
    name = PREGNANCY_NOTIFICATION_ACTION
    display_name = "Submit Pregnancy Notification"
    notification_display_name = "Pregnancy Notification"
    parent_action_names = [URINE_PREGNANCY_ACTION]
    reference_model = "meta_prn.pregnancynotification"
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "meta_prn_admin"
    priority = HIGH_PRIORITY


class OffStudyMedicationAction(ActionWithNotification):
    name = OFFSTUDY_MEDICATION_ACTION
    display_name = "Withdrawal Study Medication"
    notification_display_name = "Withdrawal Study Medication"
    parent_action_names = [
        OFFSCHEDULE_ACTION,
        LTFU_ACTION,
        SUBJECT_TRANSFER_ACTION,
        DEATH_REPORT_ACTION,
    ]
    reference_model = "meta_prn.offstudymedication"
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "meta_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True


class UnblindingRequestAction(ActionWithNotification):
    name = UNBLINDING_REQUEST_ACTION
    display_name = "Unblinding request"
    notification_display_name = " Unblinding request"
    parent_action_names = []
    reference_model = "edc_unblinding.unblindingrequest"
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "edc_unblinding_admin"
    priority = HIGH_PRIORITY

    def get_next_actions(self):
        next_actions = []
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=UNBLINDING_REVIEW_ACTION,
            required=self.reference_obj.approved == TBD,
        )
        return next_actions


class UnblindingReviewAction(PregnancyActionItemMixin, ActionWithNotification):
    name = UNBLINDING_REVIEW_ACTION
    display_name = "Unblinding review pending"
    notification_display_name = " Unblinding review needed"
    parent_action_names = [UNBLINDING_REQUEST_ACTION]
    reference_model = "edc_unblinding.unblindingreview"
    show_link_to_changelist = True
    admin_site_name = "edc_unblinding_admin"
    priority = HIGH_PRIORITY
    color_style = "info"
    create_by_user = False
    instructions = mark_safe(  # nosec B308
        "This report is to be completed by the UNBLINDING REVIEWERS only."
    )

    def get_next_actions(self):
        next_actions = []
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=self.get_next_offschedule_action(),
            required=self.reference_obj.approved == YES,
        )
        return next_actions


class SubjectTransferAction(PregnancyActionItemMixin, BaseSubjectTransferAction):
    reference_model = "meta_prn.subjecttransfer"
    admin_site_name = "meta_prn_admin"

    def get_next_actions(self):
        return [self.get_next_offschedule_action(), OFFSTUDY_MEDICATION_ACTION]


class ProtocolIncidentAction(BaseProtocolIncidentAction):
    reference_model = "meta_prn.protocolincident"
    admin_site_name = "meta_prn_admin"


site_action_items.register(EndOfStudyAction)
site_action_items.register(LossToFollowupAction)
site_action_items.register(OffscheduleAction)
site_action_items.register(OffschedulePregnancyAction)
site_action_items.register(PregnancyNotificationAction)
site_action_items.register(ProtocolIncidentAction)
site_action_items.register(SubjectTransferAction)
site_action_items.register(UnblindingRequestAction)
site_action_items.register(UnblindingReviewAction)
site_action_items.register(OffStudyMedicationAction)



# Generated by Django 3.2.4 on 2021-07-02 01:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0055_auto_20210628_2331"),
    ]

    operations = [
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="gluc_abnormal",
            new_name="glucose_abnormal",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="gluc_quantifier",
            new_name="glucose_quantifier",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="gluc_reportable",
            new_name="glucose_reportable",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="gluc_units",
            new_name="glucose_units",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="gluc_abnormal",
            new_name="glucose_abnormal",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="gluc_quantifier",
            new_name="glucose_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="gluc_reportable",
            new_name="glucose_reportable",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="gluc_units",
            new_name="glucose_units",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="gluc_value",
            new_name="glucose_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="gluc_value",
            new_name="glucose_value",
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="glucose_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood Glucose",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="glucose_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood Glucose",
            ),
        ),
    ]



# Generated by Django 3.2.13 on 2022-09-06 23:02

import uuid

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0144_auto_20220907_0157"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstudymedication",
            name="refill_identifier",
            field=models.CharField(default=uuid.uuid4, editable=False, max_length=36),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="refill_identifier",
            field=models.CharField(default=uuid.uuid4, editable=False, max_length=36),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="order_or_update_next",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Order, or update, refill for next scheduled visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="refill_start_datetime",
            field=models.DateTimeField(),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="order_or_update_next",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Order, or update, refill for next scheduled visit?",
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="refill_start_datetime",
            field=models.DateTimeField(),
        ),
    ]



# Generated by Django 4.0.5 on 2022-06-25 18:48

import django.db.models.deletion
import edc_model.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_protocol_incident",
            "0005_protocolincident_historicalprotocolincident_and_more",
        ),
        ("meta_prn", "0024_alter_protocoldeviationviolation_violation"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalprotocoldeviationviolation",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Protocol Incident",
            },
        ),
        migrations.AlterModelOptions(
            name="protocoldeviationviolation",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Protocol Incident",
                "verbose_name_plural": "Protocol Incident",
            },
        ),
        migrations.RenameField(
            model_name="historicalprotocoldeviationviolation",
            old_name="violation_other",
            new_name="incident_other",
        ),
        migrations.RenameField(
            model_name="historicalprotocoldeviationviolation",
            old_name="violation",
            new_name="incident",
        ),
        migrations.RenameField(
            model_name="historicalprotocoldeviationviolation",
            old_name="violation_datetime",
            new_name="incident_datetime",
        ),
        migrations.RenameField(
            model_name="historicalprotocoldeviationviolation",
            old_name="violation_description",
            new_name="incident_description",
        ),
        migrations.RenameField(
            model_name="historicalprotocoldeviationviolation",
            old_name="violation_reason",
            new_name="incident_reason",
        ),
        migrations.RenameField(
            model_name="protocoldeviationviolation",
            old_name="violation",
            new_name="incident",
        ),
        migrations.RenameField(
            model_name="protocoldeviationviolation",
            old_name="violation_other",
            new_name="incident_other",
        ),
        migrations.RenameField(
            model_name="protocoldeviationviolation",
            old_name="violation_datetime",
            new_name="incident_datetime",
        ),
        migrations.RenameField(
            model_name="protocoldeviationviolation",
            old_name="violation_description",
            new_name="incident_description",
        ),
        migrations.RenameField(
            model_name="protocoldeviationviolation",
            old_name="violation_reason",
            new_name="incident_reason",
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="report_type",
            field=models.CharField(
                choices=[
                    ("protocol_violation", "Protocol violation"),
                    ("protocol_deviation", "Protocol deviation"),
                ],
                max_length=25,
                verbose_name="Type of incident",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="safety_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Could this incident have an impact on safety of the participant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="short_description",
            field=models.CharField(
                help_text="Max 35 characters. Note: there is additional space below for a more detailed description",
                max_length=35,
                null=True,
                verbose_name="Provide a short description of this incident",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="study_outcomes_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Could this incident have an impact on study outcomes?",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="report_type",
            field=models.CharField(
                choices=[
                    ("protocol_violation", "Protocol violation"),
                    ("protocol_deviation", "Protocol deviation"),
                ],
                max_length=25,
                verbose_name="Type of incident",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="safety_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Could this incident have an impact on safety of the participant?",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="short_description",
            field=models.CharField(
                help_text="Max 35 characters. Note: there is additional space below for a more detailed description",
                max_length=35,
                null=True,
                verbose_name="Provide a short description of this incident",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="study_outcomes_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Could this incident have an impact on study outcomes?",
            ),
        ),
    ]



from edc_action_item.models import ActionModelMixin
from edc_model.models import BaseUuidModel
from edc_sites.models import SiteModelMixin
from edc_visit_schedule.model_mixins import OffScheduleModelMixin

from ..constants import (
    OFFSCHEDULE_ACTION,
    OFFSCHEDULE_POSTNATAL_ACTION,
    OFFSCHEDULE_PREGNANCY_ACTION,
)


class OffSchedule(SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):

    action_name = OFFSCHEDULE_ACTION
    offschedule_compare_dates_as_datetimes = False

    class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Off-schedule"
        verbose_name_plural = "Off-schedule"


class OffSchedulePregnancy(
    SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel
):

    action_name = OFFSCHEDULE_PREGNANCY_ACTION

    class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Off-schedule: Pregnancy"
        verbose_name_plural = "Off-schedule: Pregnancy"


class OffSchedulePostnatal(
    SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel
):

    action_name = OFFSCHEDULE_POSTNATAL_ACTION

    class Meta(OffScheduleModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Off-schedule: post-natal"
        verbose_name_plural = "Off-schedule: post-natal"



# Generated by Django 2.2.6 on 2019-10-21 22:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("meta_subject", "0003_auto_20191021_0534")]

    operations = [
        migrations.AlterModelOptions(
            name="historicalphysicalexam",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Physical Exam",
            },
        ),
        migrations.AlterModelOptions(
            name="physicalexam",
            options={
                "verbose_name": "Physical Exam",
                "verbose_name_plural": "Physical Exams",
            },
        ),
    ]



# Generated by Django 3.2.13 on 2022-07-04 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0042_remove_endofstudy_investigator_decision_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalendofstudy",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical End of Study",
                "verbose_name_plural": "historical End of Study",
            },
        ),
        migrations.AlterModelOptions(
            name="historicallosstofollowup",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Loss to Follow Up",
                "verbose_name_plural": "historical Loss to Follow Up",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaloffschedule",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule",
                "verbose_name_plural": "historical Off-schedule",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaloffschedulepostnatal",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule: post-natal",
                "verbose_name_plural": "historical Off-schedule: post-natal",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaloffschedulepregnancy",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule: Pregnancy",
                "verbose_name_plural": "historical Off-schedule: Pregnancy",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaloffstudymedication",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Withdrawal of Study Drug",
                "verbose_name_plural": "historical Withdrawal of Study Drug",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonschedule",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical on schedule",
                "verbose_name_plural": "historical on schedules",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonschedulepostnatal",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical on schedule postnatal",
                "verbose_name_plural": "historical on schedule postnatals",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonschedulepregnancy",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical on schedule pregnancy",
                "verbose_name_plural": "historical on schedule pregnancys",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalpregnancynotification",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Pregnancy Notification",
                "verbose_name_plural": "historical Pregnancy Notifications",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalprotocolincident",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Protocol Incident",
                "verbose_name_plural": "historical Protocol Incident",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalsubjecttransfer",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Subject Transfer",
                "verbose_name_plural": "historical Subject Transfers",
            },
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicaloffschedule",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicaloffschedulepostnatal",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicaloffschedulepregnancy",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalonschedule",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalonschedulepostnatal",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalonschedulepregnancy",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalpregnancynotification",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalsubjecttransfer",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
    ]



# Generated by Django 2.2.7 on 2019-12-13 00:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0009_auto_20191119_2331"),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomics",
            old_name="transport",
            new_name="transport_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomics",
            old_name="transport",
            new_name="transport_old",
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="buy_meds_month",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Over the last month, did you get any drugs or have a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="childcare_source_timeoff",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                null=True,
                verbose_name="How much time did a family member, friend take off work to look after your child or children?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="diabetic_expenditure_month",
            field=models.IntegerField(
                blank=True,
                editable=False,
                help_text="in Shilling",
                null=True,
                verbose_name="If YES, how much did you spend on Diabetic drugs",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="diabetic_payee",
            field=models.CharField(
                choices=[
                    ("own_cash", "Own cash"),
                    ("insurance", "Insurance"),
                    ("relative", "Relative of others paying"),
                    ("free", "Free drugs from the pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                editable=False,
                max_length=15,
                verbose_name="If YES, how did you pay or who paid for these drugs",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="higher_education",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Did you go to higher education?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="off_work_days",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                verbose_name="How much time did you take off work?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="routine_activities",
            field=models.CharField(
                choices=[
                    ("working", "Working"),
                    ("studying", "Studying"),
                    ("caring_for_children", "Caring for children"),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="What would you be doing if you had not come to the hospital?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="buy_meds_month",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Over the last month, did you get any drugs or have a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="childcare_source_timeoff",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                null=True,
                verbose_name="How much time did a family member, friend take off work to look after your child or children?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="diabetic_expenditure_month",
            field=models.IntegerField(
                blank=True,
                editable=False,
                help_text="in Shilling",
                null=True,
                verbose_name="If YES, how much did you spend on Diabetic drugs",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="diabetic_payee",
            field=models.CharField(
                choices=[
                    ("own_cash", "Own cash"),
                    ("insurance", "Insurance"),
                    ("relative", "Relative of others paying"),
                    ("free", "Free drugs from the pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                editable=False,
                max_length=15,
                verbose_name="If YES, how did you pay or who paid for these drugs",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="higher_education",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Did you go to higher education?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="off_work_days",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                verbose_name="How much time did you take off work?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="routine_activities",
            field=models.CharField(
                choices=[
                    ("working", "Working"),
                    ("studying", "Studying"),
                    ("caring_for_children", "Caring for children"),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="What would you be doing if you had not come to the hospital?",
            ),
        ),
    ]



import os
import sys

from django.conf import settings
from django.core.management.base import BaseCommand
from django.core.management.color import color_style

style = color_style()


def update_forms_reference(sender=None, **kwargs):

    from edc_form_describer import FormsReference

    from meta_subject.admin_site import meta_subject_admin
    from meta_visit_schedule.visit_schedules import visit_schedule

    sys.stdout.write(
        style.MIGRATE_HEADING("Refreshing CRF reference document for meta_subject\n")
    )
    doc_folder = os.path.join(settings.BASE_DIR, "docs")
    if not os.path.exists(doc_folder):
        os.mkdir(doc_folder)
    forms = FormsReference(visit_schedules=[visit_schedule], admin_site=meta_subject_admin)
    path = os.path.join(doc_folder, "forms_reference.md")
    forms.to_file(path=path, exists_ok=True)


class Command(BaseCommand):

    help = "Update forms reference document (.md)"

    def handle(self, *args, **options):

        update_forms_reference()



# Generated by Django 3.2.11 on 2022-03-04 02:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0032_auto_20220304_0501"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="ogtt2_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="In opinion of the clinician, should the OGTT be repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="ogtt2_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="In opinion of the clinician, should the OGTT be repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="ogtt2_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="In opinion of the clinician, should the OGTT be repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="ogtt2_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="In opinion of the clinician, should the OGTT be repeated?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="ogtt2_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="In opinion of the clinician, should the OGTT be repeated?",
            ),
        ),
    ]



from django.contrib import admin
from edc_action_item import ActionItemModelAdminMixin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin
from edc_transfer.modeladmin_mixins import SubjectTransferModelAdminMixin

from ..admin_site import meta_prn_admin
from ..forms import SubjectTransferForm
from ..models import SubjectTransfer


@admin.register(SubjectTransfer, site=meta_prn_admin)
class SubjectTransferAdmin(
    SubjectTransferModelAdminMixin,
    ActionItemModelAdminMixin,
    ModelAdminSubjectDashboardMixin,
    SimpleHistoryAdmin,
):

    form = SubjectTransferForm



from django.test import TestCase
from edc_sites import InvalidSiteError, get_site_id

from ..sites import all_sites


class SiteTests(TestCase):
    def test_all(self):

        self.assertEqual(get_site_id("hindu_mandal", sites=all_sites.get("tanzania")), 10)
        self.assertEqual(get_site_id("amana", sites=all_sites.get("tanzania")), 20)

    def test_bad(self):
        self.assertRaises(
            InvalidSiteError, get_site_id, "erik", sites=all_sites.get("tanzania")
        )



# Generated by Django 4.0.5 on 2022-06-29 13:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0112_historicalsubjectvisit_document_status_comments_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="bloodresultsrft",
            name="egfr_percent_change",
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="egfr_percent_change",
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=10, null=True),
        ),
    ]



# Generated by Django 3.2.11 on 2022-03-04 20:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0035_auto_20220304_2233"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="repeat_fasting",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="repeat_glucose_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)",
                max_length=15,
                verbose_name="Were the glucose measurements repeated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="repeat_fasting",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="repeat_glucose_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)",
                max_length=15,
                verbose_name="Were the glucose measurements repeated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="repeat_fasting",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="repeat_glucose_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)",
                max_length=15,
                verbose_name="Were the glucose measurements repeated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="repeat_fasting",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="repeat_glucose_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)",
                max_length=15,
                verbose_name="Were the glucose measurements repeated?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="repeat_fasting",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="repeat_glucose_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)",
                max_length=15,
                verbose_name="Were the glucose measurements repeated?",
            ),
        ),
    ]



# Generated by Django 3.0.4 on 2020-04-17 00:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0020_auto_20200417_0329"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="coronakap",
            name="dia_blood_pressure_r1",
        ),
        migrations.RemoveField(
            model_name="coronakap",
            name="height",
        ),
        migrations.RemoveField(
            model_name="coronakap",
            name="sys_blood_pressure_r1",
        ),
        migrations.RemoveField(
            model_name="coronakap",
            name="weight",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="dia_blood_pressure_r1",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="height",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="sys_blood_pressure_r1",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="weight",
        ),
    ]



# Generated by Django 3.2.4 on 2021-08-09 15:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0075_auto_20210809_1744"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="on_htn_treatment",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                verbose_name="Is the patient on treatment for hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="on_htn_treatment",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                verbose_name="Is the patient on treatment for hypertension?",
            ),
        ),
    ]



# Generated by Django 4.0.5 on 2022-06-29 17:26

import django.contrib.sites.managers
from django.db import migrations, models
import edc_visit_tracking.managers


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0116_egfrnotification_report_status_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="egfrnotification",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AddField(
            model_name="egfrnotification",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="egfrnotification",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalegfrnotification",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalegfrnotification",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="egfrnotification",
            name="egfr_percent_change",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Copied from RFT result eGFR section",
                max_digits=10,
                null=True,
                verbose_name="Change from baseline",
            ),
        ),
        migrations.AlterField(
            model_name="historicalegfrnotification",
            name="egfr_percent_change",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Copied from RFT result eGFR section",
                max_digits=10,
                null=True,
                verbose_name="Change from baseline",
            ),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-21 00:53

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("meta_screening", "0004_auto_20191020_0738")]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-07-22 18:30

from django.db import migrations, models
import django_crypto_fields.fields.encrypted_char_field


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0053_auto_20220704_1841"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalscreeningpartone",
            name="aou",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartone",
            name="aou_duration",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartone",
            name="aou_passed",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartthree",
            name="aou",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartthree",
            name="aou_duration",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartthree",
            name="aou_passed",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningparttwo",
            name="aou",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningparttwo",
            name="aou_duration",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningparttwo",
            name="aou_passed",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="aou",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="aou_duration",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="aou_passed",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="aou",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="aou_duration",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="aou_passed",
        ),
        migrations.AddField(
            model_name="historicalicpreferral",
            name="referred_datetime",
            field=models.DateTimeField(help_text="Date and time of referral", null=True),
        ),
        migrations.AddField(
            model_name="icpreferral",
            name="referred_datetime",
            field=models.DateTimeField(help_text="Date and time of referral", null=True),
        ),
        migrations.AlterField(
            model_name="historicalicpreferral",
            name="hospital_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalicpreferral",
            name="referred",
            field=models.BooleanField(default=False, verbose_name="Referred"),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="icpreferral",
            name="hospital_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
        migrations.AlterField(
            model_name="icpreferral",
            name="referred",
            field=models.BooleanField(default=False, verbose_name="Referred"),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
    ]



# Generated by Django 3.2.13 on 2022-09-29 14:42

import django.contrib.sites.managers
from django.db import migrations
import edc_identifier.managers
import meta_consent.models.subject_consent


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0016_auto_20220914_0547"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectconsent",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", meta_consent.models.subject_consent.SubjectConsentManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="subjectreconsent",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_identifier.managers.SubjectIdentifierManager()),
            ],
        ),
    ]



# Generated by Django 3.2.11 on 2022-04-15 14:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0108_auto_20220415_1747"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="refill_date",
            field=models.DateField(),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="refill_date",
            field=models.DateField(),
        ),
    ]



# Generated by Django 3.2.9 on 2021-11-23 13:45

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0028_auto_20210823_2353"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
    ]



from .calculated_model_mixin import CalculatedModelMixin
from .eligibility_model_mixin import EligibilityModelMixin
from .part_one_fields_model_mixin import PartOneFieldsModelMixin
from .part_three_fields_model_mixin import PartThreeFieldsModelMixin
from .part_two_fields_model_mixin import PartTwoFieldsModelMixin



from .ae_followup import AeFollowup
from .ae_initial import AeInitial
from .ae_local_review import AeLocalReview
from .ae_sponsor_review import AeSponsorReview
from .ae_susar import AeSusar
from .ae_tmg import AeTmg
from .death_report import DeathReport
from .death_report_tmg import DeathReportTmg
from .death_report_tmg_second import DeathReportTmgSecond



# Generated by Django 4.0.5 on 2022-06-27 14:17

from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0044_alter_historicalscreeningpartone_severe_htn_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True, help_text=" (Encryption: RSA local)", max_length=71, null=True
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-04-15 14:47

import edc_action_item.models.action_model_mixin
import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0022_auto_20220318_0133"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="losstofollowup",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedule",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
                (
                    "on_site",
                    edc_sites.models.CurrentSiteManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedulepostnatal",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
                (
                    "on_site",
                    edc_sites.models.CurrentSiteManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedulepregnancy",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
                (
                    "on_site",
                    edc_sites.models.CurrentSiteManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="pregnancynotification",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="protocoldeviationviolation",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
    ]



from multisite import SiteID

from .defaults import *  # noqa

print(f"Settings file {__file__}")  # noqa


SITE_ID = SiteID(default=1)
EDC_SITES_UAT_DOMAIN = True
EDC_CONSENT_BYPASS_CONSENT_DATETIME_VALIDATION = True
ALLOWED_HOSTS = [
    "amana.uat.tz.meta3.clinicedc.org",
    "hindu-mandal.uat.tz.meta3.clinicedc.org",
    "mbagala.uat.tz.meta3.clinicedc.org",
    "mnazi-moja.uat.tz.meta3.clinicedc.org",
    "mwananyamala.uat.tz.meta3.clinicedc.org",
    "temeke.uat.tz.meta3.clinicedc.org",
]

# edc_model_admin
EDC_MODEL_ADMIN_CSS_THEME = "edc_purple"
LIVE_SYSTEM = False



from django import forms
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import InlineCrfModelFormMixin

from ..constants import LIVE_AT_TERM, LIVE_PRETERM
from ..models import BirthOutcomes


class BirthOutcomesFormValidator(CrfFormValidator):
    def clean(self):
        self.required_if(
            LIVE_AT_TERM,
            LIVE_PRETERM,
            field="birth_outcome",
            field_required="birth_weight",
        )


class BirthOutcomesForm(InlineCrfModelFormMixin, forms.ModelForm):

    form_validator_cls = BirthOutcomesFormValidator

    class Meta:
        model = BirthOutcomes
        fields = "__all__"



# Generated by Django 3.2.6 on 2021-09-11 17:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0012_auto_20210911_0004"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endofstudy",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="safety_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Could this occurrence have an impact on safety of the participant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="study_outcomes_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Could this occurrence have an impact on study outcomes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="safety_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Could this occurrence have an impact on safety of the participant?",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="study_outcomes_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Could this occurrence have an impact on study outcomes?",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
    ]



# Generated by Django 3.0.4 on 2020-04-20 14:51

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0028_auto_20200420_1732"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coronakap",
            name="diabetic_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MinValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="diabetic_on_meds",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="If 'Yes', are you taking medications to control your <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hiv_pos_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MinValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first test positive?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hiv_year_started_art",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[django.core.validators.MinValueValidator(0)],
                verbose_name="If 'Yes', what year did you <u>start antiretroviral therapy</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hypertensive_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MinValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hypertensive_on_meds",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="If 'Yes', are you taking medications to control your <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="diabetic_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MinValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="diabetic_on_meds",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="If 'Yes', are you taking medications to control your <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hiv_pos_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MinValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first test positive?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hiv_year_started_art",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[django.core.validators.MinValueValidator(0)],
                verbose_name="If 'Yes', what year did you <u>start antiretroviral therapy</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hypertensive_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MinValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hypertensive_on_meds",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="If 'Yes', are you taking medications to control your <u>hypertension</u>?",
            ),
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-27 18:55

import uuid

import _socket
import django.contrib.sites.managers
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_action_item", "0024_auto_20191024_1000"),
        ("sites", "0002_alter_domain_unique"),
        ("meta_lists", "0007_auto_20200516_2356"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("meta_subject", "0039_auto_20200524_1944"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="bloodresultsfbc",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Blood Result: FBC",
                "verbose_name_plural": "Blood Results: FBC",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsglu",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Blood Result: Glucose",
                "verbose_name_plural": "Blood Results: Glucose",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultshba1c",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Blood Result: HbA1c",
                "verbose_name_plural": "Blood Results: HbA1c",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultslft",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Blood Result: LFT",
                "verbose_name_plural": "Blood Results: LFT",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultslipid",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Blood Result: Lipids",
                "verbose_name_plural": "Blood Results: Lipids",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsrft",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Blood Result: RFT",
                "verbose_name_plural": "Blood Results: RFT",
            },
        ),
        migrations.AlterModelOptions(
            name="complications",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Presence of Complications",
                "verbose_name_plural": "Presence of Complications",
            },
        ),
        migrations.AlterModelOptions(
            name="followup",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Clinic follow up: Examination",
                "verbose_name_plural": "Clinic follow up: Examination",
            },
        ),
        migrations.AlterModelOptions(
            name="followupvitals",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Clinic follow up: Vitals",
                "verbose_name_plural": "Clinic follow ups: Vitals",
            },
        ),
        migrations.AlterModelOptions(
            name="glucose",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Glucose (IFG, OGTT)",
                "verbose_name_plural": "Glucose (IFG, OGTT)",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomics",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Health Economics",
                "verbose_name_plural": "Health Economics",
            },
        ),
        migrations.AlterModelOptions(
            name="malariatest",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Malaria Test",
            },
        ),
        migrations.AlterModelOptions(
            name="medicationadherence",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Medication Adherence",
                "verbose_name_plural": "Medication Adherence",
            },
        ),
        migrations.AlterModelOptions(
            name="patienthistory",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Patient History",
                "verbose_name_plural": "Patient History",
            },
        ),
        migrations.AlterModelOptions(
            name="physicalexam",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Physical Exam",
                "verbose_name_plural": "Physical Exams",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectrequisition",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisit",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": (
                    "subject_identifier",
                    "visit_schedule_name",
                    "schedule_name",
                    "visit_code",
                    "visit_code_sequence",
                    "report_datetime",
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="urinedipsticktest",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Urine Dipstick Test",
            },
        ),
        migrations.AddField(
            model_name="followup",
            name="action_identifier",
            field=models.CharField(max_length=50, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="followup",
            name="action_item",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.ActionItem",
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="action_item_reason",
            field=models.TextField(editable=False, null=True),
        ),
        migrations.AddField(
            model_name="followup",
            name="any_other_problems_sae_grade",
            field=models.CharField(
                choices=[("3", "Grade 3"), ("4", "Grade 4"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If YES, grade 3 or 4, submit Serious Adverse Event form",
                max_length=25,
                verbose_name="If YES, what grade?",
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="parent_action_identifier",
            field=models.CharField(
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="parent_action_item",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.ActionItem",
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="related_action_identifier",
            field=models.CharField(
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="related_action_item",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.ActionItem",
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="tracking_identifier",
            field=models.CharField(max_length=30, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="action_identifier",
            field=models.CharField(db_index=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_action_item.ActionItem",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="action_item_reason",
            field=models.TextField(editable=False, null=True),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="any_other_problems_sae_grade",
            field=models.CharField(
                choices=[("3", "Grade 3"), ("4", "Grade 4"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If YES, grade 3 or 4, submit Serious Adverse Event form",
                max_length=25,
                verbose_name="If YES, what grade?",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="parent_action_identifier",
            field=models.CharField(
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_action_item.ActionItem",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="related_action_identifier",
            field=models.CharField(
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_action_item.ActionItem",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name="followup",
            name="any_other_problems_sae",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Does this event constitute an Adverse Event?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="any_other_problems_sae",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Does this event constitute an Adverse Event?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="other_missed_pill_reason",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="other_missed_pill_reason",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]



# Generated by Django 4.0.5 on 2022-07-03 19:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0041_endofstudy_transfer_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="endofstudy",
            name="investigator_decision",
        ),
        migrations.RemoveField(
            model_name="historicalendofstudy",
            name="investigator_decision",
        ),
        migrations.AddField(
            model_name="endofstudy",
            name="clinical_withdrawal_investigator_decision",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If withdrawl was an 'investigator decision', please explain ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_investigator_decision",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If withdrawl was an 'investigator decision', please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                choices=[
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If the patient was withdrawn on CLINICAL grounds, please specify PRIMARY reason",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If withdrawn for 'other' condition, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="toxicity_withdrawal_reason",
            field=models.CharField(
                choices=[
                    ("lactic_acidosis", "Development of lactic acidosis or hyperlactatemia"),
                    ("hepatomegaly", "Development of hepatomegaly with steatosis"),
                    ("OTHER", "Other toxicity (specify below)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name=" If the patient experienced an unacceptable toxicity', please explain",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="toxicity_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If 'other toxicity', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                choices=[
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If the patient was withdrawn on CLINICAL grounds, please specify PRIMARY reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If withdrawn for 'other' condition, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="toxicity_withdrawal_reason",
            field=models.CharField(
                choices=[
                    ("lactic_acidosis", "Development of lactic acidosis or hyperlactatemia"),
                    ("hepatomegaly", "Development of hepatomegaly with steatosis"),
                    ("OTHER", "Other toxicity (specify below)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name=" If the patient experienced an unacceptable toxicity', please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="toxicity_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If 'other toxicity', please specify ...",
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-07-22 01:11

from django.db import migrations
from edc_action_item.identifiers import ActionIdentifier
from edc_constants.constants import CLOSED, HIGH_PRIORITY
from tqdm import tqdm

from meta_subject.constants import MISSED_VISIT_ACTION


def update_missing_action_items_for_missed_visits(apps, schema_editor):
    actiontype_model_cls = apps.get_model("edc_action_item.actiontype")
    actionitem_model_cls = apps.get_model("edc_action_item.actionitem")
    subjectvisitmissed_model_cls = apps.get_model("meta_subject.subjectvisitmissed")
    subjectvisit_model_cls = apps.get_model("meta_subject.subjectvisit")
    action_type = actiontype_model_cls.objects.get(name=MISSED_VISIT_ACTION)

    total = subjectvisitmissed_model_cls.objects.filter(action_identifier__isnull=True).count()
    for obj in tqdm(
        subjectvisitmissed_model_cls.objects.filter(action_identifier__isnull=True),
        total=total,
    ):
        subject_visit = subjectvisit_model_cls.objects.get(id=obj.subject_visit_id)
        action_item = actionitem_model_cls.objects.create(
            subject_identifier=subject_visit.subject_identifier,
            action_identifier=ActionIdentifier(site_id=subject_visit.site_id).identifier,
            report_datetime=subject_visit.report_datetime,
            action_type=action_type,
            reference_model="meta_subject.subjectvisitmissed",
            linked_to_reference=True,
            priority=HIGH_PRIORITY,
            status=CLOSED,
            auto_created=True,
            site_id=subject_visit.site_id,
        )
        obj.action_identifier = action_item.action_identifier
        obj.save_base(update_fields=["action_identifier"])


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0130_auto_20220720_0216"),
    ]

    operations = [migrations.RunPython(update_missing_action_items_for_missed_visits)]
